@@ -6,7 +6,7 @@ from cc_plugin_ncei.tests.resources import STATIC_FILES
 class TestNCEITimeSeriesProfile(NCEITestCase):
 
     def setUp(self):
-        self.run_checker('ncei-trajectory-profile-orthogonal', STATIC_FILES['trajectory-profile'])
+        self.run_checker('ncei-trajectory-profile-orthogonal', STATIC_FILES['nodc-trajectory-profile'])
 
     def test_global_profile_score(self):
         assert not self.errors
