@@ -185,6 +185,10 @@ def get_time_variable(ds):
         candidates = ds.get_variables_by_attributes(standard_name='time')
         if len(candidates) == 1:
             return candidates[0].name
+        else:  # Look for a coordinate variable time
+            for candidate in candidates:
+                if candidate.dimensions == (candidate.name,):
+                    return candidate.name
 
     return None
 
@@ -242,8 +246,12 @@ def is_point(nc, variable):
     for req in ('x', 'y', 't'):
         if req not in cmatrix:
             return False
+    t = get_time_variable(nc)
     if cmatrix['x'] != cmatrix['y'] or cmatrix['x'] != cmatrix['t']:
         return False
+    # This is a trajectory
+    if cmatrix['t'] == (t,):
+        return False
     if len(cmatrix['x']) != 1:
         return False
     if 'z' in cmatrix and cmatrix['x'] != cmatrix['z']:
@@ -304,7 +312,6 @@ def is_multi_timeseries_orthogonal(nc, variable):
 
     for req in ('x', 'y', 't'):
         if req not in cmatrix:
-            print req, "missing"
             return False
     if len(cmatrix['x']) != 1 or cmatrix['x'] != cmatrix['y']:
         return False
@@ -387,6 +394,35 @@ def is_cf_trajectory(nc, variable):
     return False
 
 
+def is_single_trajectory(nc, variable):
+    '''
+    Returns true if the variable is a single trajectory feature
+
+    :param netCDF4.Dataset nc: An open netCDF dataset
+    :param str variable: name of the variable to check
+    '''
+    # x(t), y(t), z(t), t(t)
+    # X(t)
+    dims = nc.variables[variable].dimensions
+    cmatrix = coordinate_dimension_matrix(nc)
+
+    for req in ('x', 'y', 't'):
+        if req not in cmatrix:
+            return False
+    t = get_time_variable(nc)
+    if cmatrix['x'] != (t,):
+        return False
+    if cmatrix['x'] != cmatrix['y']:
+        return False
+    if cmatrix['x'] != cmatrix['t']:
+        return False
+    if 'z' in cmatrix and cmatrix['x'] != cmatrix['z']:
+        return False
+    if dims == cmatrix['x']:
+        return True
+    return False
+
+
 def is_profile_orthogonal(nc, variable):
     '''
     Returns true if the variable is a orthogonal profile feature type
